{
    "$graph": [
        {
            "class": "Workflow",
            "doc": "Reverse the lines in a document, then sort those lines.",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "doc": "Array of input files to be processed.",
                    "id": "#main/input"
                },
                {
                    "type": "boolean",
                    "default": true,
                    "doc": "If true, reverse (descending) sort",
                    "id": "#main/reverse_sort"
                }
            ],
            "steps": [
                {
                    "in": [
                        {
                            "source": "#main/input",
                            "id": "#main/rev/input"
                        }
                    ],
                    "out": [
                        "#main/rev/output"
                    ],
                    "scatter": "#main/rev/input",
                    "run": "#revtool.cwl",
                    "requirements": [
                        {
                            "class": "ResourceRequirement",
                            "coresMin": 1,
                            "ramMin": 100
                        }
                    ],
                    "id": "#main/rev"
                },
                {
                    "in": [
                        {
                            "source": "#main/rev/output",
                            "id": "#main/sorted/input"
                        },
                        {
                            "source": "#main/reverse_sort",
                            "id": "#main/sorted/reverse"
                        }
                    ],
                    "scatter": "#main/sorted/input",
                    "out": [
                        "#main/sorted/output"
                    ],
                    "run": "#sorttool.cwl",
                    "requirements": [
                        {
                            "class": "ResourceRequirement",
                            "coresMin": 1,
                            "ramMin": 100
                        }
                    ],
                    "id": "#main/sorted"
                }
            ],
            "id": "#main",
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/sorted/output",
                    "doc": "The output files with the lines reversed and sorted.",
                    "id": "#main/output"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "doc": "Reverse each line using the `rev` command",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "debian:stretch-slim"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {},
                    "id": "#revtool.cwl/input"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$('reversed-' + inputs.input.basename)"
                    },
                    "id": "#revtool.cwl/output"
                }
            ],
            "baseCommand": "rev",
            "stdout": "$('reversed-' + inputs.input.basename)",
            "id": "#revtool.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Sort lines using the `sort` command",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "debian:stretch-slim"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "id": "#sorttool.cwl/reverse",
                    "type": "boolean",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--reverse"
                    }
                },
                {
                    "id": "#sorttool.cwl/input",
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    }
                }
            ],
            "outputs": [
                {
                    "id": "#sorttool.cwl/output",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$('sorted-' + inputs.input.basename)"
                    }
                }
            ],
            "baseCommand": "sort",
            "stdout": "$('sorted-' + inputs.input.basename)",
            "id": "#sorttool.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
